==> entropy_labs-0.1.11-py3-none-any.whl: entropy_labs/sentinel_api_client/sentinel_api_client/models/choice.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.assistant_message import AssistantMessage


T = TypeVar("T", bound="Choice")


@_attrs_define
class Choice:
    """
    Attributes:
        message (AssistantMessage):
        stop_reason (Union[Unset, str]):
    """

    message: "AssistantMessage"
    stop_reason: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        message = self.message.to_dict()

        stop_reason = self.stop_reason

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "message": message,
            }
        )
        if stop_reason is not UNSET:
            field_dict["stop_reason"] = stop_reason

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assistant_message import AssistantMessage

        d = src_dict.copy()
        message = AssistantMessage.from_dict(d.pop("message"))

        stop_reason = d.pop("stop_reason", UNSET)

        choice = cls(
            message=message,
            stop_reason=stop_reason,
        )

        choice.additional_properties = d
        return choice

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> entropy_labs-0.1.16-py3-none-any.whl: entropy_labs/sentinel_api_client/sentinel_api_client/models/choice.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.message import Message


T = TypeVar("T", bound="Choice")


@_attrs_define
class Choice:
    """
    Attributes:
        message (Message):
        stop_reason (Union[Unset, str]):
    """

    message: "Message"
    stop_reason: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        message = self.message.to_dict()

        stop_reason = self.stop_reason

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "message": message,
            }
        )
        if stop_reason is not UNSET:
            field_dict["stop_reason"] = stop_reason

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.message import Message

        d = src_dict.copy()
        message = Message.from_dict(d.pop("message"))

        stop_reason = d.pop("stop_reason", UNSET)

        choice = cls(
            message=message,
            stop_reason=stop_reason,
        )

        choice.additional_properties = d
        return choice

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
